@@ -117,13 +117,9 @@ PXR_NAMESPACE_OPEN_SCOPE
 ///
 /// \p _name is the name of the function and must be unique across all
 /// invocations of ARCH_CONSTRUCTOR in the same translation unit.
-/// The remaining arguments should be types for the signature of the
-/// function.  The types are only to make the name unique (when mangled);
-/// the function will be called with no arguments so the arguments must
-/// not be used.  If you don't need any arguments you must use void.
 ///
 /// \hideinitializer
-#   define ARCH_CONSTRUCTOR(_name, _priority, ...)
+#   define ARCH_CONSTRUCTOR(_name, _priority)
 
 /// Macro to begin the definition of a function that should be executed by
 /// the dynamic loader when the dynamic object (library or program) is
@@ -136,13 +132,9 @@ PXR_NAMESPACE_OPEN_SCOPE
 ///
 /// \p _name is the name of the function and must be unique across all
 /// invocations of ARCH_CONSTRUCTOR in the same translation unit.
-/// The remaining arguments should be types for the signature of the
-/// function.  The types are only to make the name unique (when mangled);
-/// the function will be called with no arguments so the arguments must
-/// not be used.  If you don't need any arguments you must use void.
 ///
 /// \hideinitializer
-#   define ARCH_DESTRUCTOR(_name, _priority, ...)
+#   define ARCH_DESTRUCTOR(_name, _priority)
 
 /// Macro to begin the definition of a class that is using private inheritance
 /// to take advantage of the empty base optimization. Some compilers require
@@ -159,6 +151,7 @@ PXR_NAMESPACE_OPEN_SCOPE
 #   define ARCH_SCANF_FUNCTION(_fmt, _firstArg)	\
         __attribute__((format(scanf, _fmt, _firstArg)))
 #   define ARCH_NOINLINE __attribute__((noinline))
+#   define ARCH_ALWAYS_INLINE __attribute__((always_inline))
 #   define ARCH_UNUSED_ARG   __attribute__ ((unused))
 #   define ARCH_UNUSED_FUNCTION __attribute__((unused))
 #   define ARCH_USED_FUNCTION __attribute__((used))
@@ -169,6 +162,7 @@ PXR_NAMESPACE_OPEN_SCOPE
 #   define ARCH_PRINTF_FUNCTION(_fmt, _firstArg)
 #   define ARCH_SCANF_FUNCTION(_fmt, _firstArg)
 #   define ARCH_NOINLINE // __declspec(noinline)
+#   define ARCH_ALWAYS_INLINE
 #   define ARCH_UNUSED_ARG
 #   define ARCH_UNUSED_FUNCTION
 #   define ARCH_USED_FUNCTION
@@ -181,7 +175,7 @@ PXR_NAMESPACE_OPEN_SCOPE
 
 #endif
 
-// Helper to do on-demand static initialziation.  We need to insert per-library
+// Helper to do on-demand static initialization.  We need to insert per-library
 // static initializers if the ARCH_CONSTRUCTOR macros are used, etc, but we
 // don't want that to happen otherwise.  This mechanism makes that possible.  It
 // works by creating a class template (Arch_PerLibInit) that has hidden
@@ -226,37 +220,37 @@ struct Arch_ConstructorEntry {
 };
 
 // Emit a Arch_ConstructorEntry in the __Data,pxrctor section.
-#   define ARCH_CONSTRUCTOR(_name, _priority, ...)                             \
-    static void _name(__VA_ARGS__);                                            \
+#   define ARCH_CONSTRUCTOR(_name, _priority)                                  \
+    static void _name();                                                       \
     static const Arch_ConstructorEntry _ARCH_CAT_NOEXPAND(arch_ctor_, _name)   \
         __attribute__((used, section("__DATA,pxrctor"))) = {                   \
         reinterpret_cast<Arch_ConstructorEntry::Type>(&_name),                 \
         static_cast<unsigned>(PXR_VERSION),                                    \
         _priority                                                              \
     };                                                                         \
-    static void _name(__VA_ARGS__)
+    static void _name()
     
 // Emit a Arch_ConstructorEntry in the __Data,pxrdtor section.
-#   define ARCH_DESTRUCTOR(_name, _priority, ...)                              \
-    static void _name(__VA_ARGS__);                                            \
+#   define ARCH_DESTRUCTOR(_name, _priority)                                   \
+    static void _name();                                                       \
     static const Arch_ConstructorEntry _ARCH_CAT_NOEXPAND(arch_dtor_, _name)   \
         __attribute__((used, section("__DATA,pxrdtor"))) = {                   \
         reinterpret_cast<Arch_ConstructorEntry::Type>(&_name),                 \
         static_cast<unsigned>(PXR_VERSION),                                    \
         _priority                                                              \
     };                                                                         \
-    static void _name(__VA_ARGS__)
+    static void _name()
 
 #elif defined(ARCH_COMPILER_GCC) || defined(ARCH_COMPILER_CLANG)
 
 // The used attribute is required to prevent these apparently unused functions
 // from being removed by the linker.
-#   define ARCH_CONSTRUCTOR(_name, _priority, ...) \
+#   define ARCH_CONSTRUCTOR(_name, _priority) \
         __attribute__((used, section(".pxrctor"), constructor((_priority) + 100))) \
-        static void _name(__VA_ARGS__)
-#   define ARCH_DESTRUCTOR(_name, _priority, ...) \
+        static void _name()
+#   define ARCH_DESTRUCTOR(_name, _priority) \
         __attribute__((used, section(".pxrdtor"), destructor((_priority) + 100))) \
-        static void _name(__VA_ARGS__)
+        static void _name()
 
 #elif defined(ARCH_OS_WINDOWS)
     
@@ -287,8 +281,8 @@ struct Arch_ConstructorInit {
 // extern are to convince the compiler and linker to leave the object in the
 // final library/executable instead of stripping it out.  In clang/gcc we use
 // __attribute__((used)) to do that.
-#   define ARCH_CONSTRUCTOR(_name, _priority, ...)                             \
-    static void _name(__VA_ARGS__);                                            \
+#   define ARCH_CONSTRUCTOR(_name, _priority)                                  \
+    static void _name();                                                       \
     namespace {                                                                \
     __declspec(allocate(".pxrctor"))                                           \
     extern const Arch_ConstructorEntry                                         \
@@ -299,11 +293,11 @@ struct Arch_ConstructorInit {
     };                                                                         \
     }                                                                          \
     _ARCH_ENSURE_PER_LIB_INIT(Arch_ConstructorInit, _archCtorInit);            \
-    static void _name(__VA_ARGS__)
+    static void _name()
 
     // Emit a Arch_ConstructorEntry in the .pxrdtor section.
-#   define ARCH_DESTRUCTOR(_name, _priority, ...)                              \
-    static void _name(__VA_ARGS__);                                            \
+#   define ARCH_DESTRUCTOR(_name, _priority)                                   \
+    static void _name();                                                       \
     namespace {                                                                \
     __declspec(allocate(".pxrdtor"))                                           \
     extern const Arch_ConstructorEntry                                         \
@@ -314,7 +308,7 @@ struct Arch_ConstructorInit {
     };                                                                         \
     }                                                                          \
     _ARCH_ENSURE_PER_LIB_INIT(Arch_ConstructorInit, _archCtorInit);            \
-    static void _name(__VA_ARGS__)
+    static void _name()
 
 #else
 
