@@ -16,10 +16,10 @@
 #include "pxr/base/tf/pyObjectFinder.h"
 #include "pxr/base/tf/wrapTypeHelpers.h"
 
-#include <boost/python/bases.hpp>
-#include <boost/python/class.hpp>
-#include <boost/python/extract.hpp>
-#include <boost/python/handle.hpp>
+#include "pxr/external/boost/python/bases.hpp"
+#include "pxr/external/boost/python/class.hpp"
+#include "pxr/external/boost/python/extract.hpp"
+#include "pxr/external/boost/python/handle.hpp"
 
 #include <type_traits>
 #include <map>
@@ -29,7 +29,7 @@ PXR_NAMESPACE_OPEN_SCOPE
 
 struct Tf_PyNoticeObjectGenerator {
     typedef Tf_PyNoticeObjectGenerator This;
-    typedef boost::python::object (*MakeObjectFunc)(TfNotice const &);
+    typedef pxr_boost::python::object (*MakeObjectFunc)(TfNotice const &);
 
     // Register the generator for notice type T.
     template <typename T>
@@ -38,15 +38,15 @@ struct Tf_PyNoticeObjectGenerator {
         (*_generators)[typeid(T).name()] = This::_Generate<T>;
     }
     
-    // Produce a boost::python::object for the correct derived type of \a n.
-    TF_API static boost::python::object Invoke(TfNotice const &n);
+    // Produce a pxr_boost::python::object for the correct derived type of \a n.
+    TF_API static pxr_boost::python::object Invoke(TfNotice const &n);
 
 private:
 
     template <typename T>
-    static boost::python::object _Generate(TfNotice const &n) {
+    static pxr_boost::python::object _Generate(TfNotice const &n) {
         // Python locking is left to the caller.
-        return boost::python::object(static_cast<T const &>(n));
+        return pxr_boost::python::object(static_cast<T const &>(n));
     }
 
     static MakeObjectFunc _Lookup(TfNotice const &n);
@@ -57,14 +57,14 @@ private:
 
 struct TfPyNoticeWrapperBase : public TfType::PyPolymorphicBase {
     TF_API virtual ~TfPyNoticeWrapperBase();
-    virtual boost::python::handle<> GetNoticePythonObject() const = 0;
+    virtual pxr_boost::python::handle<> GetNoticePythonObject() const = 0;
 };
 
 template <class Notice>
 struct Tf_PyNoticeObjectFinder : public Tf_PyObjectFinderBase {
     virtual ~Tf_PyNoticeObjectFinder() {}
-    virtual boost::python::object Find(void const *objPtr) const {
-        using namespace boost::python;
+    virtual pxr_boost::python::object Find(void const *objPtr) const {
+        using namespace pxr_boost::python;
         TfPyLock lock;
         Notice const *wrapper = static_cast<Notice const *>(objPtr);
         return wrapper ? object(wrapper->GetNoticePythonObject()) : object();
@@ -95,10 +95,10 @@ public:
     // If Notice is really TfNotice, then this is the root of the hierarchy and
     // bases is empty, otherwise bases contains the base class.
     using Bases = std::conditional_t<std::is_same<NoticeType, TfNotice>::value,
-                                     boost::python::bases<>,
-                                     boost::python::bases<BaseType>>;
+                                     pxr_boost::python::bases<>,
+                                     pxr_boost::python::bases<BaseType>>;
 
-    typedef boost::python::class_<NoticeType, This, Bases> ClassType;
+    typedef pxr_boost::python::class_<NoticeType, This, Bases> ClassType;
 
     static ClassType Wrap(std::string const &name = std::string()) {
         std::string wrappedName = name;
@@ -112,14 +112,14 @@ public:
         Tf_RegisterPythonObjectFinderInternal
             (typeid(TfPyNoticeWrapper),
              new Tf_PyNoticeObjectFinder<TfPyNoticeWrapper>);
-        return ClassType(wrappedName.c_str(), boost::python::no_init)
+        return ClassType(wrappedName.c_str(), pxr_boost::python::no_init)
             .def(TfTypePythonClass());
     }
 
     // Implement the base class's virtual method.
-    virtual boost::python::handle<> GetNoticePythonObject() const {
+    virtual pxr_boost::python::handle<> GetNoticePythonObject() const {
         TfPyLock lock;
-        return boost::python::handle<>(boost::python::borrowed(_self));
+        return pxr_boost::python::handle<>(pxr_boost::python::borrowed(_self));
     }
 
     // Arbitrary argument constructor (with a leading PyObject *) which
