@@ -13,10 +13,6 @@
 #include "pxr/pxr.h"
 #include "pxr/external/boost/python/common.hpp"
 
-#ifndef PXR_USE_INTERNAL_BOOST_PYTHON
-#include <boost/python/converter/shared_ptr_deleter.hpp>
-#else
-
 namespace PXR_BOOST_NAMESPACE { namespace python { namespace converter { 
 
 struct PXR_BOOST_PYTHON_DECL shared_ptr_deleter
@@ -31,5 +27,4 @@ struct PXR_BOOST_PYTHON_DECL shared_ptr_deleter
 
 }}} // namespace PXR_BOOST_NAMESPACE::python::converter
 
-#endif // PXR_USE_INTERNAL_BOOST_PYTHON
 #endif // PXR_EXTERNAL_BOOST_PYTHON_CONVERTER_SHARED_PTR_DELETER_HPP
