@@ -14,9 +14,6 @@
 #include "pxr/pxr.h"
 #include "pxr/external/boost/python/common.hpp"
 
-#ifndef PXR_USE_INTERNAL_BOOST_PYTHON
-#include <boost/python/detail/dealloc.hpp>
-#else
 namespace PXR_BOOST_NAMESPACE { namespace python { namespace detail {
     extern "C"
     {
@@ -26,5 +23,4 @@ namespace PXR_BOOST_NAMESPACE { namespace python { namespace detail {
         }
     }
 }}} // namespace PXR_BOOST_NAMESPACE::python::detail
-#endif // PXR_USE_INTERNAL_BOOST_PYTHON
 # endif    // PXR_EXTERNAL_BOOST_PYTHON_DETAIL_DEALLOC_HPP
