@@ -37,6 +37,11 @@ public:
         return _materialPrimPath;
     }
 
+    HD_API
+    TfTokenVector GetMaterialConfigKeys() const override;
+    HD_API
+    VtValue GetMaterialConfigValue(const TfToken& key) const override;
+
     HD_API
     std::string GetModelAssetName() const override {
         return std::string();
@@ -86,6 +91,12 @@ public:
         const TfToken &nodeName,
         const TfToken &nodeType) override;
 
+    HD_API
+    virtual void SetNodeTypeInfoValue(
+        const TfToken &nodeName,
+        const TfToken &key,
+        const VtValue &value) override;
+
     HD_API
     void SetNodeParameterValue(
         const TfToken &nodeName,
