@@ -63,6 +63,9 @@ struct HdSyncRequestVector {
 ///
 struct HdDisplayStyle {
     /// The prim refine level, in the range [0, 8].
+    ///
+    /// The refinement level indicates how many iterations to apply when
+    /// subdividing subdivision surfaces or other refinable primitives.
     int refineLevel;
     
     /// Is the prim flat shaded.
@@ -71,6 +74,9 @@ struct HdDisplayStyle {
     /// Is the prim displacement shaded.
     bool displacementEnabled;
 
+    /// Is the prim overlayed on top of other prims.
+    bool displayInOverlay;
+
     /// Does the prim act "transparent" to allow occluded selection to show
     /// through?
     bool occludedSelectionShowsThrough;
@@ -87,12 +93,14 @@ struct HdDisplayStyle {
     /// - refineLevel is 0.
     /// - flatShading is disabled.
     /// - displacement is enabled.
+    /// - displayInOverlay is disabled.
     /// - occludedSelectionShowsThrough is disabled.
     /// - pointsShading is disabled.
     HdDisplayStyle()
         : refineLevel(0)
         , flatShadingEnabled(false)
         , displacementEnabled(true)
+        , displayInOverlay(false)
         , occludedSelectionShowsThrough(false)
         , pointsShadingEnabled(false)
         , materialIsFinal(false)
@@ -103,6 +111,7 @@ struct HdDisplayStyle {
     ///        Valid range is [0, 8].
     /// \param flatShading enables flat shading, defaults to false.
     /// \param displacement enables displacement shading, defaults to true.
+    /// \param displayInOverlay enables display in overlay, defaults to false.
     /// \param occludedSelectionShowsThrough controls whether the prim lets
     ///        occluded selection show through it, defaults to false.
     /// \param pointsShadingEnabled controls whether the prim's points 
@@ -113,12 +122,14 @@ struct HdDisplayStyle {
     HdDisplayStyle(int refineLevel_,
                    bool flatShading = false,
                    bool displacement = true,
+                   bool displayInOverlay_ = false,
                    bool occludedSelectionShowsThrough_ = false,
                    bool pointsShadingEnabled_ = false,
                    bool materialIsFinal_ = false)
         : refineLevel(std::max(0, refineLevel_))
         , flatShadingEnabled(flatShading)
         , displacementEnabled(displacement)
+        , displayInOverlay(displayInOverlay_)
         , occludedSelectionShowsThrough(occludedSelectionShowsThrough_)
         , pointsShadingEnabled(pointsShadingEnabled_)
         , materialIsFinal(materialIsFinal_)
@@ -137,6 +148,7 @@ struct HdDisplayStyle {
         return refineLevel == rhs.refineLevel
             && flatShadingEnabled == rhs.flatShadingEnabled
             && displacementEnabled == rhs.displacementEnabled
+            && displayInOverlay == rhs.displayInOverlay
             && occludedSelectionShowsThrough ==
                 rhs.occludedSelectionShowsThrough
             && pointsShadingEnabled == rhs.pointsShadingEnabled
@@ -223,6 +235,7 @@ struct HdModelDrawMode {
     , cardGeometry(HdModelDrawModeTokens->cross)
     {}
 
+    /// DrawModeColor is specified in the rendering color space
     HdModelDrawMode(
         TfToken const& drawMode_,
         bool applyDrawMode_=false,
@@ -472,13 +485,10 @@ public:
     HD_API
     virtual VtValue GetShadingStyle(SdfPath const &id);
 
-    /// Returns the refinement level for the given prim in the range [0,8].
-    ///
-    /// The refinement level indicates how many iterations to apply when
-    /// subdividing subdivision surfaces or other refinable primitives.
+    /// Returns the display style for the given prim.
     HD_API
     virtual HdDisplayStyle GetDisplayStyle(SdfPath const& id);
-    
+
     /// Returns a named value.
     HD_API
     virtual VtValue Get(SdfPath const& id, TfToken const& key);
@@ -524,10 +534,18 @@ public:
     // -----------------------------------------------------------------------//
 
     /// Store up to \a maxSampleCount transform samples in \a *sampleValues.
-    /// Returns the union of the authored samples and the boundaries 
-    /// of the current camera shutter interval. If this number is greater
-    /// than maxSampleCount, you might want to call this function again 
-    /// to get all the authored data.
+    /// Fills the given \a sampleValues and \a sampleTimes arrays with the
+    /// authored samples  that contribute to the delegate's current shutter
+    /// interval and their frame-relative times. If a shutter interval boundary
+    /// falls between authored sample times, the bracketing sample(s) are
+    /// included, which will lie outside the shutter interval. It is the
+    /// caller's responsibility to interpolate the bracketing samples to the
+    /// shutter interval if desired.
+    ///
+    /// If the number of contributing sample times is greater than
+    /// maxSampleCount, you might want to call this function again to get all
+    /// the authored data.
+    ///
     /// Sample times are relative to the scene delegate's current time.
     /// \see GetTransform()
     HD_API
@@ -537,9 +555,9 @@ public:
                     float *sampleTimes, 
                     GfMatrix4d *sampleValues);
 
-    // An overload of SampleTransform that explicitly takes the startTime
-    // and endTime rather than relying on the scene delegate having state
-    // about what the source of the current shutter interval should be.
+    /// An overload of SampleTransform that takes frame-relative \a startTime
+    /// and \a endTime, rather than relying on the scene delegate's internal
+    /// state to define the shutter interval.
     HD_API
     virtual size_t
     SampleTransform(SdfPath const & id,
@@ -549,17 +567,18 @@ public:
                     float *sampleTimes,
                     GfMatrix4d *sampleValues);
 
-    /// Convenience form of SampleTransform() that takes an HdTimeSampleArray.
-    /// This function returns the union of the authored transform samples 
-    /// and the boundaries of the current camera shutter interval.
+    /// Convenience form of SampleTransform that takes an HdTimeSampleArray.
+    /// This function fills the given HdTimeSampleArray with the contributing
+    /// samples and their times for the delegate's current shutter interval.
     template <unsigned int CAPACITY>
     void
     SampleTransform(SdfPath const & id,
                     HdTimeSampleArray<GfMatrix4d, CAPACITY> *sa);
 
-    /// Convenience form of SampleTransform() that takes an HdTimeSampleArray.
-    /// This function returns the union of the authored transform samples 
-    /// and the boundaries of the current camera shutter interval.
+    /// Convenience form of SampleTransform that takes an explict interval and
+    /// an HdTimeSampleArray. This function fills the given HdTimeSampleArray
+    /// with the contributing samples and their times for the given frame-
+    /// relative shutter interval.
     template <unsigned int CAPACITY>
     void
     SampleTransform(SdfPath const & id,
@@ -568,10 +587,18 @@ public:
                     HdTimeSampleArray<GfMatrix4d, CAPACITY> *sa);
 
     /// Store up to \a maxSampleCount transform samples in \a *sampleValues.
-    /// Returns the union of the authored samples and the boundaries 
-    /// of the current camera shutter interval. If this number is greater
-    /// than maxSampleCount, you might want to call this function again 
-    /// to get all the authored data.
+    /// Fills the given \a sampleValues and \a sampleTimes arrays with the
+    /// authored samples  that contribute to the delegate's current shutter
+    /// interval and their frame-relative times. If a shutter interval boundary
+    /// falls between authored sample times, the bracketing sample(s) are
+    /// included, which will lie outside the shutter interval. It is the
+    /// caller's responsibility to interpolate the bracketing samples to the
+    /// shutter interval if desired.
+    ///
+    /// If the number of contributing sample times is greater than
+    /// maxSampleCount, you might want to call this function again to get all
+    /// the authored data.
+    ///
     /// Sample times are relative to the scene delegate's current time.
     /// \see GetInstancerTransform()
     HD_API
@@ -581,10 +608,9 @@ public:
                              float *sampleTimes,
                              GfMatrix4d *sampleValues);
 
-    // An overload of SampleInstancerTransform that explicitly takes the
-    // startTime and endTime rather than relying on the scene delegate
-    // having state about what the source of the current shutter interval
-    // should be.
+    /// An overload of SampleInstancerTransform that takes frame-relative
+    /// \a startTime and \a endTime, rather than relying on the scene delegate's
+    /// internal state to define the shutter interval.
     HD_API
     virtual size_t
     SampleInstancerTransform(SdfPath const &instancerId,
@@ -594,19 +620,19 @@ public:
                              float *sampleTimes,
                              GfMatrix4d *sampleValues);
 
-    /// Convenience form of SampleInstancerTransform()
-    /// that takes an HdTimeSampleArray.
-    /// This function returns the union of the authored samples 
-    /// and the boundaries of the current camera shutter interval.
+    /// Convenience form of SampleInstancerTransform that takes an
+    /// HdTimeSampleArray. This function fills the given HdTimeSampleArray with
+    /// the contributing samples and their times for the delegate's current
+    /// shutter interval.
     template <unsigned int CAPACITY>
     void
     SampleInstancerTransform(SdfPath const &instancerId,
                              HdTimeSampleArray<GfMatrix4d, CAPACITY> *sa);
 
-    /// Convenience form of SampleInstancerTransform()
-    /// that takes an HdTimeSampleArray.
-    /// This function returns the union of the authored samples 
-    /// and the boundaries of the current camera shutter interval.
+    /// Convenience form of SampleInstancerTransform that takes an explict
+    /// interval and an HdTimeSampleArray. This function fills the given
+    /// HdTimeSampleArray with the contributing samples and their times for the
+    /// given frame-relative shutter interval.
     template <unsigned int CAPACITY>
     void
     SampleInstancerTransform(SdfPath const &instancerId,
@@ -614,10 +640,17 @@ public:
                              HdTimeSampleArray<GfMatrix4d, CAPACITY> *sa);
 
     /// Store up to \a maxSampleCount primvar samples in \a *samplesValues.
-    /// Returns the union of the authored samples and the boundaries 
-    /// of the current camera shutter interval. If this number is greater
-    /// than maxSampleCount, you might want to call this function again 
-    /// to get all the authored data.
+    /// Fills the given \a sampleValues and \a sampleTimes arrays with the
+    /// authored samples  that contribute to the delegate's current shutter
+    /// interval and their frame-relative times. If a shutter interval boundary
+    /// falls between authored sample times, the bracketing sample(s) are
+    /// included, which will lie outside the shutter interval. It is the
+    /// caller's responsibility to interpolate the bracketing samples to the
+    /// shutter interval if desired.
+    ///
+    /// If the number of contributing sample times is greater than
+    /// maxSampleCount, you might want to call this function again to get all
+    /// the authored data.
     ///
     /// Sample values that are array-valued will have a size described
     /// by the HdPrimvarDescriptor as applied to the toplogy.
@@ -638,9 +671,9 @@ public:
                   float *sampleTimes, 
                   VtValue *sampleValues);
 
-    // An overload of SamplePrimvar that explicitly takes the startTime
-    // and endTime rather than relying on the scene delegate having state
-    // about what the source of the current shutter interval should be.
+    /// An overload of SamplePrimvar that takes frame-relative \a startTime and
+    /// \a endTime, rather than relying on the scene delegate's internal state
+    /// to define the shutter interval.
     HD_API
     virtual size_t
     SamplePrimvar(SdfPath const& id, 
@@ -651,18 +684,19 @@ public:
                   float *sampleTimes, 
                   VtValue *sampleValues);
 
-    /// Convenience form of SamplePrimvar() that takes an HdTimeSampleArray.
-    /// This function returns the union of the authored samples 
-    /// and the boundaries of the current camera shutter interval.
+    /// Convenience form of SamplePrimvar that takes an HdTimeSampleArray.
+    /// This function fills the given HdTimeSampleArray with the contributing
+    /// samples and their times for the delegate's current shutter interval.
     template <unsigned int CAPACITY>
     void 
     SamplePrimvar(SdfPath const &id, 
                   TfToken const& key,
                   HdTimeSampleArray<VtValue, CAPACITY> *sa);
 
-    /// Convenience form of SamplePrimvar() that takes an HdTimeSampleArray.
-    /// This function returns the union of the authored samples 
-    /// and the boundaries of the current camera shutter interval.
+    /// Convenience form of SamplePrimvar that takes an explict interval and
+    /// an HdTimeSampleArray. This function fills the given HdTimeSampleArray
+    /// with the contributing samples and their times for the given frame-
+    /// relative shutter interval.
     template <unsigned int CAPACITY>
     void 
     SamplePrimvar(SdfPath const &id, 
@@ -670,11 +704,11 @@ public:
                   float startTime,
                   float endTime,
                   HdTimeSampleArray<VtValue, CAPACITY> *sa);
-    
-    /// SamplePrimvar() for getting an unflattened primvar and its indices. If 
-    /// \a *sampleIndices is not nullptr and the primvar has indices, it will 
-    /// return unflattened primvar samples in \a *sampleValues and the primvar's 
-    /// sampled indices in \a *sampleIndices, clearing the \a *sampleIndices 
+
+    /// SamplePrimvar() for getting an unflattened primvar and its indices. If
+    /// \a *sampleIndices is not nullptr and the primvar has indices, it will
+    /// return unflattened primvar samples in \a *sampleValues and the primvar's
+    /// sampled indices in \a *sampleIndices, clearing the \a *sampleIndices
     /// array if the primvar is not indexed.
     HD_API
     virtual size_t
@@ -685,9 +719,9 @@ public:
                          VtValue *sampleValues,
                          VtIntArray *sampleIndices);
 
-    // An overload of SampleIndexedPrimvar that explicitly takes the startTime
-    // and endTime rather than relying on the scene delegate having state
-    // about what the source of the current shutter interval should be.
+    /// An overload of SampleIndexedPrimvar that takes frame-relative
+    /// \a startTime and \a endTime, rather than relying on the scene delegate's
+    /// internal state to define the shutter interval.
     HD_API
     virtual size_t
     SampleIndexedPrimvar(SdfPath const& id, 
@@ -698,20 +732,21 @@ public:
                          float *sampleTimes, 
                          VtValue *sampleValues,
                          VtIntArray *sampleIndices);
-    
-    
-    /// Convenience form of SampleIndexedPrimvar() that takes 
-    /// HdTimeSampleArrays. This function returns the union of the authored 
-    /// samples and the boundaries of the current camera shutter interval.
+
+    /// Convenience form of SampleIndexedPrimvar that takes an
+    /// HdIndexedTimeSampleArray. This function fills the given
+    /// HdIndexedTimeSampleArray with the contributing samples and their times
+    /// for the delegate's current shutter interval.
     template <unsigned int CAPACITY>
     void 
     SampleIndexedPrimvar(SdfPath const &id, 
                          TfToken const& key,
                          HdIndexedTimeSampleArray<VtValue, CAPACITY> *sa);
 
-    /// Convenience form of SampleIndexedPrimvar() that takes 
-    /// HdTimeSampleArrays. This function returns the union of the authored 
-    /// samples and the boundaries of the current camera shutter interval.
+    /// Convenience form of SampleIndexedPrimvar that takes an explict interval
+    /// and an HdIndexedTimeSampleArray. This function fills the given
+    /// HdIndexedTimeSampleArray with the contributing samples and their times
+    /// for the given frame-relative shutter interval.
     template <unsigned int CAPACITY>
     void 
     SampleIndexedPrimvar(SdfPath const &id, 
