@@ -11,11 +11,7 @@
 #include "pxr/imaging/hd/renderDelegate.h"
 #include "pxr/imaging/hd/renderThread.h"
 
-#if defined(EMBREE_MAJOR_VERSION) && EMBREE_MAJOR_VERSION >= 4
-    #include <embree4/rtcore.h>
-#else
-    #include <embree4/rtcore.h>
-#endif // defined(EMBREE_MAJOR_VERSION) && EMBREE_MAJOR_VERSION >= 4
+#include <embree4/rtcore.h>
 
 PXR_NAMESPACE_OPEN_SCOPE
 
