@@ -1,25 +1,8 @@
 //
 // Copyright 2017 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_IMAGING_HDX_TASK_CONTROLLER_H
 #define PXR_IMAGING_HDX_TASK_CONTROLLER_H
@@ -73,16 +56,32 @@ public:
     /// -------------------------------------------------------
     /// Execution API
 
-    /// Obtain the set of tasks managed by the task controller,
+    /// Obtain paths to the tasks managed by the task controller,
     /// for image generation. The tasks returned will be different
     /// based on current renderer state.
     HDX_API
-    HdTaskSharedPtrVector const GetRenderingTasks() const;
-
-    /// Obtain the set of tasks managed by the task controller,
+    SdfPathVector GetRenderingTaskPaths() const;
+    
+    /// Obtain paths to tasks managed by the task controller,
     /// for picking.
     HDX_API
-    HdTaskSharedPtrVector const GetPickingTasks() const;
+    SdfPathVector GetPickingTaskPaths() const;
+
+    /// \deprecated Use GetRenderingTaskPaths
+    ///
+    /// Deprecated in preparation of changing to an
+    /// HdxTaskControllerSceneIndex.
+    ///
+    HDX_API
+    HdTaskSharedPtrVector GetRenderingTasks() const;
+
+    /// \deprecated Use GetPickingTaskPaths
+    ///
+    /// Deprecated in preparation of changing to an
+    /// HdxTaskControllerSceneIndex.
+    ///
+    HDX_API
+    HdTaskSharedPtrVector GetPickingTasks() const;
 
     /// -------------------------------------------------------
     /// Rendering API
@@ -154,7 +153,7 @@ public:
     /// -------------------------------------------------------
     /// Camera and Framing API
     
-    /// Set the size of the render buffers baking the AOVs.
+    /// Set the size of the render buffers backing the AOVs.
     /// GUI applications should set this to the size of the window.
     ///
     HDX_API
@@ -237,6 +236,15 @@ public:
     /// Progressive Image Generation
 
     /// Return whether the image has converged.
+    ///
+    /// \deprecated
+    ///
+    /// Instead, checks whether HdxTask::IsConverged for a
+    /// task in the render index for each path in GetRenderingTaskPaths().
+    ///
+    /// Deprecated in preparation of changing to an
+    /// HdxTaskControllerSceneIndex.
+    ///
     HDX_API
     bool IsConverged() const;
 
