@@ -202,10 +202,18 @@ PcpComposeSiteRelocates(PcpNodeRef const &node, SdfRelocatesMap *result)
 }
 
 /// Has prim specs.
+PCP_API
+bool
+PcpComposeSiteHasPrimSpecs(PcpLayerStackRefPtr const &layerStack,
+                           SdfPath const &path,
+                           const std::unordered_set<SdfLayerHandle, TfHash>& 
+                               layersToIgnore);
+
 PCP_API
 bool
 PcpComposeSiteHasPrimSpecs(PcpLayerStackRefPtr const &layerStack,
                            SdfPath const &path);
+
 inline bool
 PcpComposeSiteHasPrimSpecs(PcpNodeRef const &node)
 {
