@@ -1,25 +1,8 @@
 //
 // Copyright 2023 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_SDF_PREDICATE_LIBRARY_H
 #define PXR_USD_SDF_PREDICATE_LIBRARY_H
@@ -33,7 +16,6 @@
 #include "pxr/base/vt/value.h"
 
 #include "pxr/usd/sdf/predicateExpression.h"
-#include "pxr/usd/sdf/invoke.hpp"
 
 #include <initializer_list>
 #include <memory>
@@ -653,10 +635,9 @@ private:
                 std::integral_constant<bool, TakesArbitraryArgs> {},
                 args, boundArgs, typedArgs);
             return [typedArgs, fn](DomainType const &obj) {
-                // invoke fn with obj & typedArgs. (std::apply in '17).
                 return SdfPredicateFunctionResult {
-                    invoke_hpp::apply(fn, std::tuple_cat(
-                                          std::make_tuple(obj), typedArgs))
+                    std::apply(fn, 
+                        std::tuple_cat(std::make_tuple(obj), typedArgs))
                 };
             };
         }
