@@ -1,25 +1,8 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_IMAGING_USD_IMAGING_INSTANCE_ADAPTER_H
 #define PXR_USD_IMAGING_USD_IMAGING_INSTANCE_ADAPTER_H
@@ -27,6 +10,7 @@
 /// \file usdImaging/instanceAdapter.h
 
 #include "pxr/pxr.h"
+#include "pxr/usdImaging/usdImaging/api.h"
 #include "pxr/usdImaging/usdImaging/primAdapter.h"
 
 #include "pxr/base/tf/hashmap.h"
@@ -92,30 +76,32 @@ class UsdImagingInstanceAdapter : public UsdImagingPrimAdapter
 {
 public:
     using BaseAdapter = UsdImagingPrimAdapter;
-
-    UsdImagingInstanceAdapter();
-    virtual ~UsdImagingInstanceAdapter();
-
-    virtual SdfPath Populate(
+    
+    USDIMAGING_API
+    SdfPath Populate(
         UsdPrim const& prim, 
         UsdImagingIndexProxy* index, 
         UsdImagingInstancerContext const* instancerContext = nullptr) override;
 
-    virtual bool ShouldCullChildren() const override;
+    USDIMAGING_API
+    bool ShouldCullChildren() const override;
 
-    virtual bool IsInstancerAdapter() const override;
+    USDIMAGING_API
+    bool IsInstancerAdapter() const override;
 
     // ---------------------------------------------------------------------- //
     /// \name Parallel Setup and Resolve
     // ---------------------------------------------------------------------- //
     
-    virtual void TrackVariability(UsdPrim const& prim,
+    USDIMAGING_API
+    void TrackVariability(UsdPrim const& prim,
                                   SdfPath const& cachePath,
                                   HdDirtyBits* timeVaryingBits,
                                   UsdImagingInstancerContext const* 
                                       instancerContext = NULL) const override;
 
-    virtual void UpdateForTime(UsdPrim const& prim,
+    USDIMAGING_API
+    void UpdateForTime(UsdPrim const& prim,
                                SdfPath const& cachePath, 
                                UsdTimeCode time,
                                HdDirtyBits requestedBits,
@@ -126,19 +112,23 @@ public:
     /// \name Change Processing 
     // ---------------------------------------------------------------------- //
 
-    virtual HdDirtyBits ProcessPropertyChange(UsdPrim const& prim,
+    USDIMAGING_API
+    HdDirtyBits ProcessPropertyChange(UsdPrim const& prim,
                                               SdfPath const& cachePath,
                                               TfToken const& propertyName) 
                                                   override;
 
-    virtual void ProcessPrimResync(SdfPath const& cachePath,
+    USDIMAGING_API
+    void ProcessPrimResync(SdfPath const& cachePath,
                                    UsdImagingIndexProxy* index) override;
 
-    virtual void ProcessPrimRemoval(SdfPath const& cachePath,
+    USDIMAGING_API
+    void ProcessPrimRemoval(SdfPath const& cachePath,
                                    UsdImagingIndexProxy* index) override;
 
 
-    virtual void MarkDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkDirty(UsdPrim const& prim,
                            SdfPath const& cachePath,
                            HdDirtyBits dirty,
                            UsdImagingIndexProxy* index) override;
@@ -146,27 +136,33 @@ public:
     // As this adapter hijacks the adapter for the child prim
     // We need to forward these messages on, in case the child
     // adapter needs them
-    virtual void MarkRefineLevelDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkRefineLevelDirty(UsdPrim const& prim,
                                       SdfPath const& cachePath,
                                       UsdImagingIndexProxy* index) override;
 
-    virtual void MarkReprDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkReprDirty(UsdPrim const& prim,
                                SdfPath const& cachePath,
                                UsdImagingIndexProxy* index) override;
 
-    virtual void MarkCullStyleDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkCullStyleDirty(UsdPrim const& prim,
                                     SdfPath const& cachePath,
                                     UsdImagingIndexProxy* index) override;
 
-    virtual void MarkRenderTagDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkRenderTagDirty(UsdPrim const& prim,
                                     SdfPath const& cachePath,
                                     UsdImagingIndexProxy* index) override;
 
-    virtual void MarkTransformDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkTransformDirty(UsdPrim const& prim,
                                     SdfPath const& cachePath,
                                     UsdImagingIndexProxy* index) override;
 
-    virtual void MarkVisibilityDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkVisibilityDirty(UsdPrim const& prim,
                                      SdfPath const& cachePath,
                                      UsdImagingIndexProxy* index) override;
 
@@ -174,21 +170,26 @@ public:
     /// \name Instancing
     // ---------------------------------------------------------------------- //
 
+    USDIMAGING_API
     std::vector<VtArray<TfToken>> GetInstanceCategories(
         UsdPrim const& prim) override;
 
+    USDIMAGING_API
     GfMatrix4d GetInstancerTransform(UsdPrim const& instancerPrim,
                                      SdfPath const& instancerPath,
                                      UsdTimeCode time) const override;
 
+    USDIMAGING_API
     SdfPath GetInstancerId(
         UsdPrim const& usdPrim,
         SdfPath const& cachePath) const override;
 
+    USDIMAGING_API
     SdfPathVector GetInstancerPrototypes(
         UsdPrim const& usdPrim,
         SdfPath const& cachePath) const override;
 
+    USDIMAGING_API
     size_t SampleInstancerTransform(UsdPrim const& instancerPrim,
                                     SdfPath const& instancerPath,
                                     UsdTimeCode time,
@@ -196,6 +197,7 @@ public:
                                     float *sampleTimes,
                                     GfMatrix4d *sampleValues) override;
 
+    USDIMAGING_API
     size_t SampleTransform(UsdPrim const& prim, 
                            SdfPath const& cachePath,
                            UsdTimeCode time, 
@@ -203,6 +205,7 @@ public:
                            float *sampleTimes,
                            GfMatrix4d *sampleValues) override;
 
+    USDIMAGING_API
     size_t SamplePrimvar(UsdPrim const& usdPrim,
                          SdfPath const& cachePath,
                          TfToken const& key,
@@ -212,55 +215,69 @@ public:
                          VtValue *sampleValues,
                          VtIntArray *sampleIndices) override;
 
+    USDIMAGING_API
     TfToken GetPurpose(
         UsdPrim const& usdPrim, 
         SdfPath const& cachePath,
         TfToken const& instanceInheritablePurpose) const override;
 
+    USDIMAGING_API
     PxOsdSubdivTags GetSubdivTags(UsdPrim const& usdPrim,
                                   SdfPath const& cachePath,
                                   UsdTimeCode time) const override;
 
+    USDIMAGING_API
     VtValue GetTopology(UsdPrim const& prim,
                         SdfPath const& cachePath,
                         UsdTimeCode time) const override;
 
+    USDIMAGING_API
     HdCullStyle GetCullStyle(UsdPrim const& prim,
                              SdfPath const& cachePath,
                              UsdTimeCode time) const override;
 
+    USDIMAGING_API
     GfRange3d GetExtent(UsdPrim const& usdPrim, 
                         SdfPath const& cachePath, 
                         UsdTimeCode time) const override;
 
+    USDIMAGING_API
+    bool IsChildPath(const SdfPath& path) const override;
+
     bool GetVisible(UsdPrim const& usdPrim, 
                     SdfPath const& cachePath,
                     UsdTimeCode time) const override;
 
+    USDIMAGING_API
     bool GetDoubleSided(UsdPrim const& prim, 
                         SdfPath const& cachePath, 
                         UsdTimeCode time) const override;
 
+    USDIMAGING_API
     GfMatrix4d GetTransform(UsdPrim const& prim, 
                             SdfPath const& cachePath,
                             UsdTimeCode time,
                             bool ignoreRootTransform = false) const override;
 
+    USDIMAGING_API
     SdfPath GetMaterialId(UsdPrim const& prim, 
                           SdfPath const& cachePath, 
                           UsdTimeCode time) const override;
 
+    USDIMAGING_API
     VtValue GetLightParamValue(
         const UsdPrim& prim,
         const SdfPath& cachePath,
         const TfToken& paramName,
         UsdTimeCode time) const override;
     
+    USDIMAGING_API
     VtValue GetMaterialResource(
         const UsdPrim& prim,
         const SdfPath& cachePath,
         UsdTimeCode time) const override;
 
+    USDIMAGING_API
     HdExtComputationInputDescriptorVector
     GetExtComputationInputs(UsdPrim const& prim,
                             SdfPath const& cachePath,
@@ -268,12 +285,14 @@ public:
                                     const override;
 
     
+    USDIMAGING_API
     HdExtComputationOutputDescriptorVector
     GetExtComputationOutputs(UsdPrim const& prim,
                              SdfPath const& cachePath,
                              const UsdImagingInstancerContext* instancerContext)
                                     const override;
 
+    USDIMAGING_API
     HdExtComputationPrimvarDescriptorVector
     GetExtComputationPrimvars(
             UsdPrim const& prim,
@@ -281,6 +300,7 @@ public:
             HdInterpolation interpolation,
             const UsdImagingInstancerContext* instancerContext) const override;
 
+    USDIMAGING_API
     VtValue 
     GetExtComputationInput(
             UsdPrim const& prim,
@@ -289,18 +309,21 @@ public:
             UsdTimeCode time,
             const UsdImagingInstancerContext* instancerContext) const override;
 
+    USDIMAGING_API
     std::string 
     GetExtComputationKernel(
             UsdPrim const& prim,
             SdfPath const& cachePath,
             const UsdImagingInstancerContext* instancerContext) const override;
 
+    USDIMAGING_API
     VtValue
     GetInstanceIndices(UsdPrim const& instancerPrim,
                        SdfPath const& instancerCachePath,
                        SdfPath const& prototypeCachePath,
                        UsdTimeCode time) const override;
 
+    USDIMAGING_API
     VtValue Get(UsdPrim const& prim,
                 SdfPath const& cachePath,
                 TfToken const& key,
@@ -311,7 +334,8 @@ public:
     /// \name Nested instancing support
     // ---------------------------------------------------------------------- //
 
-    virtual GfMatrix4d GetRelativeInstancerTransform(
+    USDIMAGING_API
+    GfMatrix4d GetRelativeInstancerTransform(
         SdfPath const &parentInstancerPath,
         SdfPath const &instancerPath,
         UsdTimeCode time) const override;
@@ -320,17 +344,20 @@ public:
     /// \name Picking & selection
     // ---------------------------------------------------------------------- //
 
-    virtual SdfPath GetScenePrimPath(
+    USDIMAGING_API
+    SdfPath GetScenePrimPath(
         SdfPath const& cachePath,
         int instanceIndex,
         HdInstancerContext *instancerContext) const override;
 
-    virtual SdfPathVector GetScenePrimPaths(
+    USDIMAGING_API
+    SdfPathVector GetScenePrimPaths(
         SdfPath const& cachePath,
         std::vector<int> const& instanceIndices,
         std::vector<HdInstancerContext> *instancerCtxs) const override;
 
-    virtual bool PopulateSelection( 
+    USDIMAGING_API
+    bool PopulateSelection( 
         HdSelection::HighlightMode const& highlightMode,
         SdfPath const &cachePath,
         UsdPrim const &usdPrim,
@@ -342,12 +369,14 @@ public:
     /// \name Volume field information
     // ---------------------------------------------------------------------- //
 
-    virtual HdVolumeFieldDescriptorVector
+    USDIMAGING_API
+    HdVolumeFieldDescriptorVector
     GetVolumeFieldDescriptors(UsdPrim const& usdPrim, SdfPath const &id,
                               UsdTimeCode time) const override;
 
 protected:
-    virtual void _RemovePrim(SdfPath const& cachePath,
+    USDIMAGING_API
+    void _RemovePrim(SdfPath const& cachePath,
                              UsdImagingIndexProxy* index) override final;
 
 private:
@@ -367,20 +396,14 @@ private:
     // Returns true if the given prim serves as an instancer.
     bool _PrimIsInstancer(UsdPrim const& prim) const;
 
-    // Inserts prototype prims for the given \p usdPrim into the \p index.
-    // Any inserted gprims will be inserted under a special path combining
-    // \p instancerPath and \p protoName.
+    // Inserts prototype prims for the usdPrim given by \p iter into the
+    // \p index. Any inserted gprims will be inserted under a special path
+    // combining \p ctx.instancerCachePath and \p ctx.childName.
     SdfPath 
     _InsertProtoPrim(UsdPrimRange::iterator *iter,
-                     const TfToken& protoName,
-                     SdfPath materialId,
-                     TfToken drawMode,
-                     TfToken inheritablePurpose,
-                     SdfPath instancerPath,
-                     UsdImagingPrimAdapterSharedPtr const& primAdapter,
-                     UsdImagingPrimAdapterSharedPtr const& instancerAdapter,
-                     UsdImagingIndexProxy* index,
-                     bool *isLeafInstancer);
+                     const UsdImagingPrimAdapterSharedPtr& primAdapter,
+                     const UsdImagingInstancerContext& ctx,
+                     UsdImagingIndexProxy* index);
 
     // For a usd path, collects the instancers to resync.
     void _ResyncPath(SdfPath const& cachePath,
@@ -647,7 +670,6 @@ private:
     _ProtoPrimToInstancerMap _protoPrimToInstancerMap;
 };
 
-
 PXR_NAMESPACE_CLOSE_SCOPE
 
 #endif // PXR_USD_IMAGING_USD_IMAGING_INSTANCE_ADAPTER_H
