@@ -1,62 +1,46 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_IMAGING_USD_IMAGING_POINT_INSTANCER_ADAPTER_H
 #define PXR_USD_IMAGING_USD_IMAGING_POINT_INSTANCER_ADAPTER_H
 
 /// \file usdImaging/pointInstancerAdapter.h
 
-#include "pxr/pxr.h"
-#include "pxr/base/tf/denseHashMap.h"
-#include "pxr/usdImaging/usdImaging/version.h"
-#include "pxr/usdImaging/usdImaging/primAdapter.h"
-#include "pxr/usdImaging/usdImaging/gprimAdapter.h"
+#include "pxr/usdImaging/usdImaging/api.h"
+#include "pxr/usdImaging/usdImaging/instanceablePrimAdapter.h"
 
+#include "pxr/usd/sdf/path.h"
+
+#include "pxr/base/tf/denseHashMap.h"
+
+#include "pxr/pxr.h"
+
+#include <atomic>
 #include <mutex>
 
 PXR_NAMESPACE_OPEN_SCOPE
 
-
 /// Delegate support for UsdGeomPointInstancer
 ///
-class UsdImagingPointInstancerAdapter : public UsdImagingPrimAdapter 
+class UsdImagingPointInstancerAdapter : public UsdImagingInstanceablePrimAdapter 
 {
 public:
-    using BaseAdapter = UsdImagingPrimAdapter;
+    using BaseAdapter = UsdImagingInstanceablePrimAdapter;
 
-    UsdImagingPointInstancerAdapter()
-        : BaseAdapter()
-        { }
-    virtual ~UsdImagingPointInstancerAdapter();
-
-    virtual SdfPath Populate(
+    USDIMAGING_API
+    SdfPath Populate(
         UsdPrim const& prim,
         UsdImagingIndexProxy* index,
         UsdImagingInstancerContext const* instancerContext = nullptr) override;
 
-    virtual bool ShouldCullChildren() const override;
+    USDIMAGING_API
+    bool ShouldCullChildren() const override;
 
-    virtual bool IsInstancerAdapter() const override;
+    USDIMAGING_API
+    bool IsInstancerAdapter() const override;
 
     // ---------------------------------------------------------------------- //
     /// \name Scene Index Support
@@ -87,13 +71,15 @@ public:
     /// \name Parallel Setup and Resolve
     // ---------------------------------------------------------------------- //
     
-    virtual void TrackVariability(UsdPrim const& prim,
+    USDIMAGING_API
+    void TrackVariability(UsdPrim const& prim,
                                   SdfPath const& cachePath,
                                   HdDirtyBits* timeVaryingBits,
                                   UsdImagingInstancerContext const* 
                                       instancerContext = NULL) const override;
 
-    virtual void UpdateForTime(UsdPrim const& prim,
+    USDIMAGING_API
+    void UpdateForTime(UsdPrim const& prim,
                                SdfPath const& cachePath, 
                                UsdTimeCode time,
                                HdDirtyBits requestedBits,
@@ -104,52 +90,64 @@ public:
     /// \name Change Processing 
     // ---------------------------------------------------------------------- //
 
-    virtual HdDirtyBits ProcessPropertyChange(UsdPrim const& prim,
+    USDIMAGING_API
+    HdDirtyBits ProcessPropertyChange(UsdPrim const& prim,
                                               SdfPath const& cachePath,
                                               TfToken const& propertyName) 
                                                 override;
 
-    virtual void ProcessPrimResync(SdfPath const& cachePath,
+    USDIMAGING_API
+    void ProcessPrimResync(SdfPath const& cachePath,
                                    UsdImagingIndexProxy* index) override;
 
-    virtual void ProcessPrimRemoval(SdfPath const& cachePath,
+    USDIMAGING_API
+    void ProcessPrimRemoval(SdfPath const& cachePath,
                                     UsdImagingIndexProxy* index) override;
 
-    virtual void MarkDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkDirty(UsdPrim const& prim,
                            SdfPath const& cachePath,
                            HdDirtyBits dirty,
                            UsdImagingIndexProxy* index) override;
 
-    virtual void MarkRefineLevelDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkRefineLevelDirty(UsdPrim const& prim,
                                       SdfPath const& cachePath,
                                       UsdImagingIndexProxy* index) override;
 
-    virtual void MarkReprDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkReprDirty(UsdPrim const& prim,
                                SdfPath const& cachePath,
                                UsdImagingIndexProxy* index) override;
 
-    virtual void MarkCullStyleDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkCullStyleDirty(UsdPrim const& prim,
                                     SdfPath const& cachePath,
                                     UsdImagingIndexProxy* index) override;
 
-    virtual void MarkRenderTagDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkRenderTagDirty(UsdPrim const& prim,
                                     SdfPath const& cachePath,
                                     UsdImagingIndexProxy* index) override;
 
-    virtual void MarkTransformDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkTransformDirty(UsdPrim const& prim,
                                     SdfPath const& cachePath,
                                     UsdImagingIndexProxy* index) override;
 
-    virtual void MarkVisibilityDirty(UsdPrim const& prim,
+    USDIMAGING_API
+    void MarkVisibilityDirty(UsdPrim const& prim,
                                      SdfPath const& cachePath,
                                      UsdImagingIndexProxy* index) override;
 
-    virtual void MarkLightParamsDirty(
+    USDIMAGING_API
+    void MarkLightParamsDirty(
         const UsdPrim& prim,
         const SdfPath& cachePath,
         UsdImagingIndexProxy* index) override;
 
-    virtual void MarkCollectionsDirty(
+    USDIMAGING_API
+    void MarkCollectionsDirty(
         const UsdPrim& prim,
         const SdfPath& cachePath,
         UsdImagingIndexProxy* index) override;
@@ -158,10 +156,12 @@ public:
     /// \name Instancing
     // ---------------------------------------------------------------------- //
 
+    USDIMAGING_API
     GfMatrix4d GetInstancerTransform(UsdPrim const& instancerPrim,
                                      SdfPath const& instancerPath,
                                      UsdTimeCode time) const override;
 
+    USDIMAGING_API
     size_t SampleInstancerTransform(UsdPrim const& instancerPrim,
                                     SdfPath const& instancerPath,
                                     UsdTimeCode time,
@@ -169,19 +169,23 @@ public:
                                     float *sampleTimes,
                                     GfMatrix4d *sampleValues) override;
 
+    USDIMAGING_API
     SdfPath GetInstancerId(
         UsdPrim const& usdPrim,
         SdfPath const& cachePath) const override;
 
+    USDIMAGING_API
     SdfPathVector GetInstancerPrototypes(
         UsdPrim const& usdPrim,
         SdfPath const& cachePath) const override;
 
+    USDIMAGING_API
     GfMatrix4d GetTransform(UsdPrim const& prim, 
                             SdfPath const& cachePath,
                             UsdTimeCode time,
                             bool ignoreRootTransform = false) const override;
 
+    USDIMAGING_API
     size_t SampleTransform(UsdPrim const& prim, 
                            SdfPath const& cachePath,
                            UsdTimeCode time, 
@@ -189,6 +193,7 @@ public:
                            float  *sampleTimes,
                            GfMatrix4d *sampleValues) override;
 
+    USDIMAGING_API
     size_t SamplePrimvar(UsdPrim const& usdPrim,
                          SdfPath const& cachePath,
                          TfToken const& key,
@@ -198,63 +203,78 @@ public:
                          VtValue *sampleValues,
                          VtIntArray *sampleIndices) override;
 
+    USDIMAGING_API
     PxOsdSubdivTags GetSubdivTags(UsdPrim const& usdPrim,
                                   SdfPath const& cachePath,
                                   UsdTimeCode time) const override;
 
+    USDIMAGING_API
+    bool IsChildPath(const SdfPath& path) const override;
+
     bool GetVisible(UsdPrim const& prim, 
                     SdfPath const& cachePath,
                     UsdTimeCode time) const override;
 
+    USDIMAGING_API
     TfToken GetPurpose(
         UsdPrim const& usdPrim, 
         SdfPath const& cachePath,
         TfToken const& instanceInheritablePurpose) const override;
 
+    USDIMAGING_API
     VtValue GetTopology(UsdPrim const& prim,
                         SdfPath const& cachePath,
                         UsdTimeCode time) const override;
 
+    USDIMAGING_API
     HdCullStyle GetCullStyle(UsdPrim const& prim,
                              SdfPath const& cachePath,
                              UsdTimeCode time) const override;
 
+    USDIMAGING_API
     GfRange3d GetExtent(UsdPrim const& usdPrim, 
                         SdfPath const& cachePath, 
                         UsdTimeCode time) const override;
 
+    USDIMAGING_API
     bool GetDoubleSided(UsdPrim const& usdPrim, 
                    SdfPath const& cachePath, 
                    UsdTimeCode time) const override;
 
 
+    USDIMAGING_API
     SdfPath GetMaterialId(UsdPrim const& prim, 
                           SdfPath const& cachePath, 
                           UsdTimeCode time) const override;
 
+    USDIMAGING_API
     VtValue GetLightParamValue(
         const UsdPrim& prim,
         const SdfPath& cachePath,
         const TfToken& paramName,
         UsdTimeCode time) const override;
     
+    USDIMAGING_API
     VtValue GetMaterialResource(
         const UsdPrim& prim,
         const SdfPath& cachePath,
         UsdTimeCode time) const override;
 
+    USDIMAGING_API
     HdExtComputationInputDescriptorVector
     GetExtComputationInputs(UsdPrim const& prim,
                             SdfPath const& cachePath,
                             const UsdImagingInstancerContext* instancerContext)
                                     const override;
 
+    USDIMAGING_API
     HdExtComputationOutputDescriptorVector
     GetExtComputationOutputs(UsdPrim const& prim,
                              SdfPath const& cachePath,
                              const UsdImagingInstancerContext* instancerContext)
                                     const override;
 
+    USDIMAGING_API
     HdExtComputationPrimvarDescriptorVector
     GetExtComputationPrimvars(
             UsdPrim const& prim,
@@ -262,6 +282,7 @@ public:
             HdInterpolation interpolation,
             const UsdImagingInstancerContext* instancerContext) const override;
 
+    USDIMAGING_API
     VtValue 
     GetExtComputationInput(
             UsdPrim const& prim,
@@ -270,18 +291,21 @@ public:
             UsdTimeCode time,
             const UsdImagingInstancerContext* instancerContext) const override;
 
+    USDIMAGING_API
     std::string 
     GetExtComputationKernel(
             UsdPrim const& prim,
             SdfPath const& cachePath,
             const UsdImagingInstancerContext* instancerContext) const override;
 
+    USDIMAGING_API
     VtValue
     GetInstanceIndices(UsdPrim const& instancerPrim,
                        SdfPath const& instancerCachePath,
                        SdfPath const& prototypeCachePath,
                        UsdTimeCode time) const override;
 
+    USDIMAGING_API
     VtValue Get(UsdPrim const& prim,
                 SdfPath const& cachePath,
                 TfToken const& key,
@@ -292,7 +316,8 @@ public:
     /// \name Nested instancing support
     // ---------------------------------------------------------------------- //
 
-    virtual GfMatrix4d GetRelativeInstancerTransform(
+    USDIMAGING_API
+    GfMatrix4d GetRelativeInstancerTransform(
         SdfPath const &instancerPath,
         SdfPath const &protoInstancerPath,
         UsdTimeCode time) const override;
@@ -301,17 +326,20 @@ public:
     /// \name Picking & selection
     // ---------------------------------------------------------------------- //
 
-    virtual SdfPath GetScenePrimPath(
+    USDIMAGING_API
+    SdfPath GetScenePrimPath(
         SdfPath const& cachePath,
         int instanceIndex,
         HdInstancerContext *instancerContext) const override;
 
-    virtual SdfPathVector GetScenePrimPaths(
+    USDIMAGING_API
+    SdfPathVector GetScenePrimPaths(
         SdfPath const& cachePath,
         std::vector<int> const& instanceIndices,
         std::vector<HdInstancerContext> *instancerCtxs) const override;
 
-    virtual bool PopulateSelection(
+    USDIMAGING_API
+    bool PopulateSelection(
         HdSelection::HighlightMode const& highlightMode,
         SdfPath const &cachePath,
         UsdPrim const &usdPrim,
@@ -323,12 +351,33 @@ public:
     /// \name Volume field information
     // ---------------------------------------------------------------------- //
 
-    virtual HdVolumeFieldDescriptorVector
+    USDIMAGING_API
+    HdVolumeFieldDescriptorVector
     GetVolumeFieldDescriptors(UsdPrim const& usdPrim, SdfPath const &id,
                               UsdTimeCode time) const override;
 
 protected:
-    virtual void _RemovePrim(SdfPath const& cachePath,
+    friend class UsdImagingInstanceAdapter;
+    // ---------------------------------------------------------------------- //
+    /// \name Utility
+    // ---------------------------------------------------------------------- //
+    
+    // Given the USD path for a prim of this adapter's type, returns
+    // the prim's Hydra cache path. This version will reserve a path in
+    // the adapter's instancer data map for the given point instancer USD
+    // path, including any necessary variant selection path.
+    //
+    // This method is marked const, but it is not const! If called with the
+    // path of a populated point instancer, it will modify the instancer data
+    // cache and return a new path. 
+    USDIMAGING_API
+    SdfPath
+    ResolveCachePath(
+        const SdfPath& usdPath,
+        const UsdImagingInstancerContext* ctx = nullptr) const override;
+        
+    USDIMAGING_API
+    void _RemovePrim(SdfPath const& cachePath,
                              UsdImagingIndexProxy* index) override final;
 
 private:
@@ -464,19 +513,20 @@ private:
         mutable bool variableVisibility;
         mutable bool visible;
         mutable UsdTimeCode visibleTime;
+        mutable std::atomic_bool initialized = std::atomic_bool(false);
     };
 
     // A map of instancer data, one entry per instancer prim that has been
-    // populated.
+    // populated. This must be mutable so we can modify it in ResolveCachePath.
     // Note: this is accessed in multithreaded code paths and must be protected
     typedef std::unordered_map<SdfPath /*instancerPath*/, 
                                _InstancerData, 
                                SdfPath::Hash> _InstancerDataMap;
-    _InstancerDataMap _instancerData;
+    mutable _InstancerDataMap _instancerData;
+    
+    inline static std::atomic_int _globalVariantCounter = std::atomic_int(0);
 };
 
-
-
 PXR_NAMESPACE_CLOSE_SCOPE
 
 #endif // PXR_USD_IMAGING_USD_IMAGING_POINT_INSTANCER_ADAPTER_H
