@@ -1,31 +1,14 @@
 //
 // Copyright 2018 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_IMAGING_USD_SKEL_IMAGING_SKELETON_ADAPTER_H
 #define PXR_USD_IMAGING_USD_SKEL_IMAGING_SKELETON_ADAPTER_H
 
 #include "pxr/pxr.h"
-#include "pxr/usdImaging/usdImaging/primAdapter.h"
+#include "pxr/usdImaging/usdImaging/instanceablePrimAdapter.h"
 #include "pxr/usdImaging/usdSkelImaging/api.h"
 
 #include "pxr/imaging/hd/meshTopology.h"
@@ -38,18 +21,16 @@
 
 #include <unordered_map>
 
-
 PXR_NAMESPACE_OPEN_SCOPE
 
-
-/// \class UsdImagingSkeletonAdapter
+/// \class UsdSkelImagingSkeletonAdapter
 ///
-/// Support for drawing bones of a UsdSkelSkeleton.  
+/// Prim adapter for UsdSkel's Skeleton.
 ///
-class UsdSkelImagingSkeletonAdapter : public UsdImagingPrimAdapter 
+class UsdSkelImagingSkeletonAdapter : public UsdImagingInstanceablePrimAdapter 
 {
 public:
-    using BaseAdapter = UsdImagingPrimAdapter;
+    using BaseAdapter = UsdImagingInstanceablePrimAdapter;
 
     UsdSkelImagingSkeletonAdapter()
         : BaseAdapter()
@@ -209,12 +190,14 @@ public:
                             const UsdImagingInstancerContext *instancerContext) 
                                         const override;
 
+    USDSKELIMAGING_API
     HdExtComputationOutputDescriptorVector
     GetExtComputationOutputs(UsdPrim const& prim,
                              SdfPath const& cachePath,
                              const UsdImagingInstancerContext* instancerContext)
                                     const override;
 
+    USDSKELIMAGING_API
     HdExtComputationPrimvarDescriptorVector
     GetExtComputationPrimvars(
             UsdPrim const& prim,
@@ -222,7 +205,7 @@ public:
             HdInterpolation interpolation,
             const UsdImagingInstancerContext* instancerContext) const override;
 
-    USDIMAGING_API
+    USDSKELIMAGING_API
     VtValue 
     GetExtComputationInput(
             UsdPrim const& prim,
@@ -231,7 +214,7 @@ public:
             UsdTimeCode time,
             const UsdImagingInstancerContext* instancerContext) const override;
 
-    USDIMAGING_API
+    USDSKELIMAGING_API
     size_t
     SampleExtComputationInput(
             UsdPrim const& prim,
@@ -243,7 +226,7 @@ public:
             float *sampleTimes,
             VtValue *sampleValues) override;
 
-    USDIMAGING_API
+    USDSKELIMAGING_API
     std::string 
     GetExtComputationKernel(
             UsdPrim const& prim,
@@ -258,6 +241,30 @@ public:
                 UsdTimeCode time,
                 VtIntArray *outIndices) const override;
 
+    // ---------------------------------------------------------------------- //
+    /// \name Scene Index Support
+    // ---------------------------------------------------------------------- //
+    USDSKELIMAGING_API
+    TfTokenVector GetImagingSubprims(UsdPrim const &prim) override;
+
+    USDSKELIMAGING_API
+    TfToken GetImagingSubprimType(
+            UsdPrim const &prim,
+            TfToken const &subprim) override;
+
+    USDSKELIMAGING_API
+    HdContainerDataSourceHandle GetImagingSubprimData(
+            UsdPrim const& prim,
+            TfToken const& subprim,
+            const UsdImagingDataSourceStageGlobals &stageGlobals) override;
+
+    USDSKELIMAGING_API
+    HdDataSourceLocatorSet InvalidateImagingSubprim(
+            UsdPrim const& prim,
+            TfToken const& subprim,
+            TfTokenVector const& properties,
+            UsdImagingPropertyInvalidationType invalidationType) override;
+    
 protected:
     // ---------------------------------------------------------------------- //
     /// \name Change Processing API (protected)
