@@ -15,7 +15,7 @@
 #   define USDSHADEVALIDATORS_API_TEMPLATE_STRUCT(...)
 #   define USDSHADEVALIDATORS_API_LOCAL
 #else
-#   if defined(USDSHADEVALIDATORS_API_EXPORTS)
+#   if defined(USDSHADEVALIDATORS_EXPORTS)
 #       define USDSHADEVALIDATORS_API ARCH_EXPORT
 #       define USDSHADEVALIDATORS_API_TEMPLATE_CLASS(...)                     \
            ARCH_EXPORT_TEMPLATE(class, __VA_ARGS__)
