@@ -15,7 +15,7 @@
 #   define USDSKELVALIDATORS_API_TEMPLATE_STRUCT(...)
 #   define USDSKELVALIDATORS_API_LOCAL
 #else
-#   if defined(USDSKELVALIDATORS_API_EXPORTS)
+#   if defined(USDSKELVALIDATORS_EXPORTS)
 #       define USDSKELVALIDATORS_API ARCH_EXPORT
 #       define USDSKELVALIDATORS_API_TEMPLATE_CLASS(...)                      \
            ARCH_EXPORT_TEMPLATE(class, __VA_ARGS__)
